import { Directive, ElementRef, HostListener, Input, NgModule } from '@angular/core';

class Ng4FittextDirective {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
        this.fittext = true;
        this.activateOnResize = true;
        this.minFontSize = -1 / 0;
        this.maxFontSize = 1 / 0;
        this.compression = 1;
        this.setFontSize = () => {
            if (this.fittext) {
                let /** @type {?} */ containerWidth, /** @type {?} */ fontSize;
                const /** @type {?} */ windowWidth = window.screen.width;
                const /** @type {?} */ parentWidth = this.container.parentElement.clientWidth;
                parentWidth > windowWidth ? containerWidth = windowWidth : containerWidth = parentWidth;
                fontSize = Math.max(Math.min(containerWidth / (this.compression * 10), this.maxFontSize), this.minFontSize);
                return this.el.nativeElement.style.setProperty('font-size', (fontSize).toString() + 'px');
            }
        };
        this.onResize = () => {
            if (this.activateOnResize) {
                this.setFontSize();
            }
        };
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes['compression'] && !changes['compression'].firstChange) {
            this.setFontSize();
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.setFontSize();
    }
}
Ng4FittextDirective.decorators = [
    { type: Directive, args: [{
                selector: '[fittext]'
            },] },
];
/**
 * @nocollapse
 */
Ng4FittextDirective.ctorParameters = () => [
    { type: ElementRef, },
];
Ng4FittextDirective.propDecorators = {
    'fittext': [{ type: Input, args: ['fittext',] },],
    'container': [{ type: Input, args: ['container',] },],
    'activateOnResize': [{ type: Input, args: ['activateOnResize',] },],
    'minFontSize': [{ type: Input, args: ['minFontSize',] },],
    'maxFontSize': [{ type: Input, args: ['maxFontSize',] },],
    'compression': [{ type: Input, args: ['compression',] },],
    'onResize': [{ type: HostListener, args: ['window:resize', ['$event'],] },],
};

class Ng4FittextModule {
}
Ng4FittextModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    Ng4FittextDirective
                ],
                exports: [Ng4FittextDirective]
            },] },
];
/**
 * @nocollapse
 */
Ng4FittextModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { Ng4FittextModule, Ng4FittextDirective as ɵa };
//# sourceMappingURL=ng4-fittext.js.map
